import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Creates an index for a data collection.
 *
 * The index can't be used immediately, as the process of generating the index takes time.
 * You can check whether an index is ready by calling List Indexes.
 *
 * Note that when an index fails to create, the failed index still occupies a slot.
 * To remove the failed index and free up the slot for a new index, call Drop Index.
 */
export declare function createIndex(payload: object): RequestOptionsFactory<any>;
/**
 * Removes an index from a data collection.
 *
 * The process of dropping an index from a collection takes time.
 * You can check whether an index has been dropped by calling List Indexes.
 */
export declare function dropIndex(payload: object): RequestOptionsFactory<any>;
/**
 * Lists all indexes defined for a data collection.
 *
 * When an index's status is `ACTIVE`, it is ready to use.
 * While it is still being created, its status is `BUILDING`.
 *
 * When an index's status is `DROPPED`, it has been dropped successfully.
 * While it is still in the process of being removed, its status is `DROPPING`.
 */
export declare function listIndexes(payload: object): RequestOptionsFactory<any>;
/** Lists available indexes limits */
export declare function listAvailableIndexes(payload: object): RequestOptionsFactory<any>;
